import { SnipSessionData } from "@snip/auth/session";
import { PermissionACLData } from "@snip/database/types";

interface MockConfig {
    book_perms: Omit<
        PermissionACLData,
        "entity_id" | "resource_id" | "entity_type" | "resource_type"
    >;
    session: SnipSessionData;
    headers: Headers;
}

const mockConfig: MockConfig = {
    book_perms: {
        id: -1,
        pRead: true,
        pWrite: true,
        pDelete: true,
        pACL: true,
    },
    session: {
        user: {
            id: 42,
            email_verified: true,
            created: Date.now(),
        },
        save: jest.fn(() => Promise.resolve()),
        destroy: jest.fn(),
        updateConfig: jest.fn(),
    },
    headers: new Headers(),
};

export function resetMockConfig() {
    mockConfig.book_perms = {
        id: -1,
        pRead: true,
        pWrite: true,
        pDelete: true,
        pACL: true,
    };
    mockConfig.session = {
        user: {
            id: 42,
            email_verified: true,
            created: Date.now(),
        },
        save: jest.fn(() => Promise.resolve()),
        destroy: jest.fn(),
        updateConfig: jest.fn(),
    };
    mockConfig.headers = new Headers();
}

export function setSessionType(
    type: "user" | "ui_token" | "api_token" | "none",
) {
    if (type === "ui_token") {
        mockConfig.session.anonymous = {
            tokens: [
                {
                    id: 1,
                    expires_at: Date.now() + 1000,
                    book_id: 1,
                },
            ],
        };
        delete mockConfig.session.user;
        delete mockConfig.session.api;
    }
    if (type === "api_token") {
        mockConfig.session.api = {
            identifier: "test",
        };
        delete mockConfig.session.user;
        delete mockConfig.session.anonymous;
    }
    if (type === "user") {
        mockConfig.session.user = {
            id: 42,
            email_verified: true,
            created: Date.now(),
        };
        delete mockConfig.session.api;
        delete mockConfig.session.anonymous;
    }
    if (type === "none") {
        delete mockConfig.session.user;
        delete mockConfig.session.api;
        delete mockConfig.session.anonymous;
    }
}

export default mockConfig;
