"use server";

import { errorToMessage } from "lib/actions/errorToMessage";
import { getSessionAction } from "lib/session";

import service from "@snip/database";
import { UserData } from "@snip/database/types";

import { validateEmail, validatePW } from "components/form/validation";
async function _signupSubmitAction(
    prevState: {
        message?: string;
        userData?: UserData;
    },
    formData: FormData,
): Promise<{ userData: UserData; message?: string }> {
    const rawForm = {
        email: formData.get("email") as string,
        password: formData.get("password") as string,
    };

    if (!rawForm.email || !rawForm.password) {
        throw Error("No Email or Password given!");
    }

    // Validate email and password
    const email_valid = validateEmail(rawForm.email);
    const pw_valid = validatePW(rawForm.password);
    if (!email_valid) {
        throw Error("Invalid Email given!");
    }
    if (!pw_valid) {
        throw Error("Invalid Password given!");
    }

    // Create user in database
    let userData;
    try {
        userData = await service.user.signup(rawForm.email, rawForm.password);
        const session = await getSessionAction();
        session.user = {
            id: userData.id,
            email_verified: userData.emailValidated,
            created: userData.created.getTime(),
        };
        await session.save();
    } catch (e) {
        if (e.message.includes("User already exists")) {
            throw Error("Email already registered!");
        }
        throw Error("Internal server error!");
    }

    return { userData };
}

export const signupSubmitAction = errorToMessage(_signupSubmitAction);
