"use server";

import { getSessionAction } from "lib/session";

import { verifyUserToken } from "@snip/auth/tokens/emailVerify";
import service from "@snip/database";
import { UserData } from "@snip/database/types";

export async function checkVerified(
    token?: string,
): Promise<{ user?: UserData; error?: string }> {
    const session = await getSessionAction();

    //Strip all spaces from token
    if (token) {
        token = token.replace(/\s/g, "");
    }

    // Get user and check if email is already verified
    let user;
    try {
        user = await service.user.getById(session.user.id);
        if (user.emailValidated) {
            //overwrite just in case
            session.user.email_verified = true;
            await session.save();
            return { user };
        }
    } catch (error) {
        return { error: "User not found" };
    }

    // Check if token is given
    if (token) {
        try {
            const success = await verifyUserToken(user, token);
            if (success) {
                session.user.email_verified = true;
                await service.user.verify(user.email);
                user.emailValidated = true;
                await session.save();
                return { user };
            } else {
                return { error: "Invalid token", user };
            }
        } catch (error) {
            return { error: error.message };
        }
    }
    return { user };
}

export async function checkVerifiedFormAction(
    prev: {
        user?: UserData;
        error?: string;
    },
    formData: FormData,
) {
    const rawForm = {
        email: formData.get("token") as string,
    };

    // Check token valid
    const { user, error } = await checkVerified(rawForm.email);

    return {
        user,
        error,
    };
}
