"use client";
import useUser from "lib/hooks/useUser";
import {
    createContext,
    Dispatch,
    SetStateAction,
    useContext,
    useEffect,
    useRef,
    useState,
} from "react";

import { ToolContextProps } from "../types";

export interface DoodleContextI {
    // The current tool
    colorList: string[];
    setColorList: (colorList: string[]) => void;

    // Current color
    currentColor: string;
    currentColorIdx: number;
    setCurrentColorIdx: Dispatch<SetStateAction<number>>;
    // Pen size
    size: number;
    setSize: (size: number) => void;

    // Pen smoothing
    smoothing: number;
    setSmoothing: (smoothing: number) => void;

    // Touch events as move
    touchMove: boolean;
    setTouchMove: (touchMove: boolean) => void;
}

const DoodleToolContext = createContext<DoodleContextI>({
    colorList: ["#000000"],
    setColorList: () => {},

    currentColorIdx: 0,
    setCurrentColorIdx: () => {},
    currentColor: "#000000",

    size: 4,
    setSize: () => {},

    smoothing: 1,
    setSmoothing: () => {},

    touchMove: false,
    setTouchMove: () => {},
});

export function DoodleToolContextProvider({ children }: ToolContextProps) {
    const { config } = useUser(true);
    const mounted = useRef(false);

    const [colorList, setColorList] = useState([
        "#000000",
        "#0000ff",
        "#ff0000",
        "#00ff00",
    ]);
    const [currentColorIdx, setCurrentColorIdx] = useState(0);

    const [size, setSize] = useState(5);
    const [smoothing, setSmoothing] = useState(0.5);

    const [touchMove, setTouchMove] = useState(false);

    // Initial sync from db
    useEffect(() => {
        if (mounted.current || !config) return;
        mounted.current = true;

        setColorList(config.pen_colors);
        setCurrentColorIdx(config.pen_colors.indexOf(config.pen_color) || 0);
        setSize(config.pen_size);
        setSmoothing(config.pen_smoothing);

        return () => {
            mounted.current = false;
        };
    }, [config]);

    return (
        <DoodleToolContext.Provider
            value={{
                colorList,
                setColorList,
                currentColor: colorList[currentColorIdx],
                currentColorIdx,
                setCurrentColorIdx,
                size,
                setSize,
                smoothing,
                setSmoothing,
                touchMove,
                setTouchMove,
            }}
        >
            {children}
        </DoodleToolContext.Provider>
    );
}

export function useDoodleToolContext() {
    return useContext(DoodleToolContext);
}
