import { cm2px } from "./utils";

export function render_lined(
    ctx: CanvasRenderingContext2D | OffscreenCanvasRenderingContext2D,
    lwidth = 7,
    scaling = true
) {
    // Scale to db coordinates
    const max_db = [1400, 2000];
    let scale = max_db[1] / max_db[0];
    if (!scaling) scale = 1;

    // Padding and line delta
    const delta_y = cm2px(lwidth / 10) * scale;
    //const padding_x = (delta_y / 2) * scale;
    const padding_y = (delta_y / 2) * scale;

    // Visual properties
    ctx.strokeStyle = "#d3d3d3"; // Light grey
    ctx.lineWidth = 1;

    // Convert to canvas transform
    const transform = ctx.getTransform().invertSelf();
    const width =
        transform.a * ctx.canvas.width +
        transform.b * ctx.canvas.height +
        transform.e;
    const height =
        transform.c * ctx.canvas.width +
        transform.d * ctx.canvas.height +
        transform.f;

    // Determine how many lines can fit on the canvas
    const num_horizontal = Math.floor((height - padding_y) / delta_y);

    // Calc starting point such that it is centered
    const start_x = 0;
    const start_y = (height - num_horizontal * delta_y) / 2;

    // Draw horizontal lines
    for (let i = 0; i < num_horizontal + 1; i++) {
        ctx.beginPath();
        ctx.moveTo(start_x, start_y + i * delta_y);
        ctx.lineTo(width - start_x, start_y + i * delta_y);
        ctx.stroke();
    }
    return;
}
