import { type SocketData } from "../../types";
import { allowedPage } from "../../utils/auth";

export function setupLaserPointerPrefix({ socket }: SocketData) {
    /** Receive a new laser pointer positions and propagate it to all
     * other sockets
     */
    socket.on("laserPointer:pos", async (xy: [number, number], pageId) => {
        if (!allowedPage(socket, pageId)) {
            return socket.emit("error", {
                message: "Unauthorized access to page",
            });
        }

        //logWS(socket, "laserPointer", socket.data.id);

        socket
            .to("page-" + String(pageId))
            .emit(
                "laserPointer:pos",
                xy,
                pageId,
                socket.id,
                socket.data.email,
                Date.now(),
            );
    });
}
