import { sign, verify } from "jsonwebtoken";

import { GroupMemberData, UserData } from "@snip/database/types";
import { config } from "@snip/utils/config";

export interface GroupInviteToken {
    time: number;
    type: "group_invite";
    // group that user is invited to
    group_id: number;
    group_name: string;
    // user who invited other user
    by_id: number;
    by_email: string;
    //user who was invited
    user_email: string;
    user_id: number;
}

export async function verifyGroupInviteToken(
    potentialMember: GroupMemberData,
    token: string,
) {
    // try to unseal token
    let tokenData: GroupInviteToken;
    try {
        tokenData = (await verify(
            token,
            config.EMAIL.TOKEN_SECRET +
                potentialMember.user_id +
                potentialMember.joined_at.getTime(),
        )) as GroupInviteToken;
    } catch (error) {
        throw new Error("Invalid token");
    }

    if (
        !tokenData.user_email ||
        !tokenData.user_id ||
        !tokenData.group_id ||
        tokenData.user_id !== potentialMember.user_id ||
        tokenData.group_id !== potentialMember.group_id ||
        tokenData.type !== "group_invite"
    ) {
        throw new Error("Invalid token");
    }

    return tokenData;
}

export async function signGroupInviteToken(
    user: UserData,
    potentialMember: GroupMemberData,
    inviter: UserData,
    group: { id: number; name: string },
): Promise<string> {
    const data = {
        time: Date.now(),
        type: "group_invite",
        //group
        group_id: group.id,
        group_name: group.name,
        //inviter
        by_id: inviter.id,
        by_email: inviter.email,
        //user
        user_email: user.email,
        user_id: user.id,
    };

    return await sign(
        data,
        config.EMAIL.TOKEN_SECRET +
            potentialMember.user_id +
            potentialMember.joined_at.getTime(),
        {
            expiresIn: "48h",
        },
    );
}
